# Introduction

This library brings a simple set of filesystem-oriented dialogs to
[Textual](https://textual.textualize.io) applications. If you have a need to
give your users a dialog that lets them pick a file for opening, a file for
saving, or they need to pick a directory, this might be the library for you.

# Examples

## Opening a file

=== "Opening a file"

    ```{.textual path="docs/examples/index/open_a_file.py"}
    ```

=== "open_a_file.py"

    ```py
    --8<-- "docs/examples/index/open_a_file.py"
    ```

## Saving a file

=== "Saving a file"

    ```{.textual path="docs/examples/index/save_a_file.py"}
    ```

=== "save_a_file.py"

    ```py
    --8<-- "docs/examples/index/save_a_file.py"
    ```

## Selecting a directory

=== "Selecting a directory"

    ```{.textual path="docs/examples/index/select_a_directory.py"}
    ```

=== "select_a_directory.py"

    ```py
    --8<-- "docs/examples/index/select_a_directory.py"
    ```

[//]: # (index.md ends here)
